.. _api_reports:

====================================
Reports *(autoclean.step_functions)*
====================================

This section covers the report classes that provide functionality for generating reports in the Pipeline class.

.. currentmodule:: autoclean.step_functions.reports

Report Functions
----------------

.. autosummary::
   :toctree: generated/
   :template: autosummary/function.rst
   :nosignatures:

   create_run_report
   update_task_processing_log
   create_json_summary
   generate_bad_channels_tsv




